# Expected results for test isolates


## test_isolate_01

### FASTA / BLAST

#### Resistance genes

**gene**: blaB-2
**identity**: 100.0
**Aln length**: 750
**Gene lenght**: 750
**pos in ref**: 1..750
**pos in ctg**: 631..1380
**phenotype**: amoxicillin, ampicillin, ticarcillin
**PMID**: 10858348
**Acc no.**: AF189300
**Notes**: Chromosomal class B carbapenamase

#### Point mutations

**gene**: gyrB
No mutations


## test_isolate_02

### FASTA / BLAST

#### Resistance genes

**gene**: blaCTX-M-33
**identity**: 100.0
**Aln length**: 876
**Gene lenght**: 876
**pos in ref**: 1..876
**pos in ctg**: 1..876
**phenotype**: amoxicillin, ampicillin, aztreonam, cefepime, cefotaxime, ceftazidime, ceftriaxone, piperacillin, ticarcillin
**PMID**: 17234386
**Acc no.**: AY238472
**Notes**: Class A

#### Point mutations

No genes found.
